import { ComponentClass } from 'react';
import Taro, { Component, Config } from '@tarojs/taro';
import { View, Button, Text, Input } from '@tarojs/components';
import { connect } from '@tarojs/redux';

import Vcode from '../../components/Vcode/Vcode';
import './Login.scss';

type PageStateProps = {
  APP_ID: string;
};

type PageOwnProps = {};

type PageState = {
  loginWay: string;
  vcode: string;
  account: string;
  pwd: string;
  tel: string;
  code: string;
};

type IProps = PageStateProps & PageOwnProps;

interface Login {
  props: IProps;
  state: PageState;
}

@connect(({ constants }) => ({
  APP_ID: constants.APP_ID,
}))
class Login extends Component {
  config: Config = {
    navigationBarTitleText: '多彩校园',
  };

  constructor(props) {
    super(props);
    this.state = {
      loginWay: 'tel',
      vcode: '',
      account: '',
      pwd: '',
      tel: '',
      code: '',
    };
  }
  toggleLoginWay(state: string) {
    this.setState({
      loginWay: state,
    });
  }

  render() {
    const { loginWay } = this.state;
    return (
      <View className='Login'>
        <View className='Login-title'>欢迎来到多彩校园</View>
        <View className='Login-loginWay-tab'>
          <Text
            className={`Login-loginWay-item ${
              loginWay === 'account' ? 'active' : ''
            }`}
            onClick={() => this.toggleLoginWay('account')}
          >
            账号登录
          </Text>
          <Text
            className={`Login-loginWay-item ${
              loginWay === 'tel' ? 'active' : ''
            }`}
            onClick={() => this.toggleLoginWay('tel')}
          >
            手机号登录
          </Text>
        </View>
        {loginWay === 'account' ? (
          <View>
            <Input
              className='Login-input'
              placeholder-class='Login-input-placeholder'
              placeholder='请输入账号手机号'
            />
            <Input
              className='Login-input'
              placeholder-class='Login-input-placeholder'
              password
              placeholder='请输入密码'
            />
          </View>
        ) : (
          <View>
            <Input
              className='Login-input'
              type='number'
              placeholder-class='Login-input-placeholder'
              placeholder='请输入手机号'
              maxLength={11}
            />
            <View className='Login-vcodeBox'>
              <Input
                className='Login-input'
                type='number'
                placeholder-class='Login-input-placeholder'
                placeholder='请输入验证码'
                maxLength={6}
              />
              <Vcode vcode-classname='Login-Vcode' text='获取验证码' />
            </View>
          </View>
        )}

        <View className='Login-regist'>
          还没有账号？
          <Text className='Login-regist-btn'>注册</Text>
        </View>
        <Button className='Login-btn'>登录</Button>
      </View>
    );
  }
}

export default Login as ComponentClass<PageOwnProps, PageState>;
